summaryrefslogtreecommitdiff
path: root/sfx2
diff options
context:
space:
mode:
authorIvo Hinkelmann <ihi@openoffice.org>2008-04-24 18:15:48 +0000
committerIvo Hinkelmann <ihi@openoffice.org>2008-04-24 18:15:48 +0000
commitce9b779de4d323f5b0f8e33ca9bfd327aa6cdf89 (patch)
tree8f54ee5a596129f9be3799357b77cc8d364bebd1 /sfx2
parent85f5bfc1fa5a6b8e4b21f5ab016a21c8d94736bf (diff)
INTEGRATION: CWS mav32 (1.200.4); FILE MERGED
2008/04/18 15:11:34 mav 1.200.4.1: #i88424# fix the locking check on saving
Diffstat (limited to 'sfx2')
-rw-r--r--sfx2/source/doc/docfile.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sfx2/source/doc/docfile.cxx b/sfx2/source/doc/docfile.cxx
index 8d3007be96..d78de05c02 100644
--- a/sfx2/source/doc/docfile.cxx
+++ b/sfx2/source/doc/docfile.cxx
@@ -7,7 +7,7 @@
* OpenOffice.org - a multi-platform office productivity suite
*
* $RCSfile: docfile.cxx,v $
- * $Revision: 1.201 $
+ * $Revision: 1.202 $
*
* This file is part of OpenOffice.org.
*
@@ -993,9 +993,9 @@ sal_Bool SfxMedium::LockOrigFileOnDemand( sal_Bool bLoading )
SFX_ITEMSET_ARG( GetItemSet(), pReadOnlyItem, SfxBoolItem, SID_DOC_READONLY, sal_False);
// no locking is necessary if the document is explicitly opened as copy
SFX_ITEMSET_ARG( GetItemSet(), pTemplateItem, SfxBoolItem, SID_TEMPLATE, sal_False);
- bResult = ( pTemplateItem && pTemplateItem->GetValue() );
+ bResult = ( bLoading && pTemplateItem && pTemplateItem->GetValue() );
try
{
@@ -993,9 +993,9 @@ sal_Bool SfxMedium::LockOrigFileOnDemand( sal_Bool bLoading )
SFX_ITEMSET_ARG( GetItemSet(), pReadOnlyItem, SfxBoolItem, SID_DOC_READONLY, sal_False);
- // no locking is necessary if the document is explicitly opened as copy
+ // no locking is necessary on loading if the document is explicitly opened as copy
SFX_ITEMSET_ARG( GetItemSet(), pTemplateItem, SfxBoolItem, SID_TEMPLATE, sal_False);